@@ -10,26 +10,27 @@
 #ifndef GLOSSARYWINDOW_H
 #define GLOSSARYWINDOW_H
 
-#include <kmainwindow.h>
-#include <ktextedit.h>
-#include <QTreeView>
 #include <QListView>
 #include <QStringListModel>
+#include <QTreeView>
+#include <kmainwindow.h>
+#include <ktextedit.h>
 
-class QListView;
-//class KTextEdit;
+// class KTextEdit;
 class QLineEdit;
 class KComboBox;
-//class QStringListModel;
+// class QStringListModel;
 
-
-class AuxTextEdit: public KTextEdit
+class AuxTextEdit : public KTextEdit
 {
     Q_OBJECT
 public:
-    explicit AuxTextEdit(QWidget* parent = nullptr): KTextEdit(parent) {}
+    explicit AuxTextEdit(QWidget *parent = nullptr)
+        : KTextEdit(parent)
+    {
+    }
 
-    void focusOutEvent(QFocusEvent* e) override
+    void focusOutEvent(QFocusEvent *e) override
     {
         Q_UNUSED(e);
         Q_EMIT editingFinished();
@@ -38,18 +39,20 @@ Q_SIGNALS:
     void editingFinished();
 };
 
-class TermListView: public QListView
+class TermListView : public QListView
 {
     Q_OBJECT
 public:
-    explicit TermListView(QWidget* parent = nullptr): QListView(parent) {}
+    explicit TermListView(QWidget *parent = nullptr)
+        : QListView(parent)
+    {
+    }
 
 public Q_SLOTS:
     void rmTerms();
     void addTerm();
 };
 
-
 namespace GlossaryNS
 {
 class GlossaryTreeView;
@@ -57,7 +60,7 @@ class Glossary;
 class TermsListModel;
 class GlossarySortFilterProxyModel;
 
-class GlossaryWindow: public KMainWindow
+class GlossaryWindow : public KMainWindow
 {
     Q_OBJECT
 public:
@@ -67,7 +70,7 @@ public:
 
 public Q_SLOTS:
     void currentChanged(int);
-    void showEntryInEditor(const QByteArray& id);
+    void showEntryInEditor(const QByteArray &id);
     void showDefinitionForLang(int);
     void newTermEntry(QString _english, QString _target);
     void newTermEntry();
@@ -76,66 +79,67 @@ public Q_SLOTS:
     void restore();
     bool save();
     void applyEntryChange();
-    void selectEntry(const QByteArray& id);
+    void selectEntry(const QByteArray &id);
     void setFocus();
 
 private:
-    QWidget* m_editor;
-    GlossaryTreeView* m_browser;
-    TermsListModel* m_sourceTermsModel;
-    TermsListModel* m_targetTermsModel;
-    GlossarySortFilterProxyModel* m_proxyModel;
-    QLineEdit* m_filterEdit;
+    QWidget *m_editor;
+    GlossaryTreeView *m_browser;
+    TermsListModel *m_sourceTermsModel;
+    TermsListModel *m_targetTermsModel;
+    GlossarySortFilterProxyModel *m_proxyModel;
+    QLineEdit *m_filterEdit;
 
-    KComboBox* m_subjectField;
-    KTextEdit* m_definition;
-    KComboBox* m_definitionLang;
-    QListView* m_sourceTermsView;
-    QListView* m_targetTermsView;
+    KComboBox *m_subjectField;
+    KTextEdit *m_definition;
+    KComboBox *m_definitionLang;
+    QListView *m_sourceTermsView;
+    QListView *m_targetTermsView;
 
     bool m_reactOnSignals;
     QByteArray m_id;
     QString m_defLang;
 };
 
-class GlossaryTreeView: public QTreeView
+class GlossaryTreeView : public QTreeView
 {
     Q_OBJECT
 public:
     explicit GlossaryTreeView(QWidget *parent = nullptr);
     ~GlossaryTreeView() override = default;
 
-    void currentChanged(const QModelIndex& current, const QModelIndex& previous) override;
+    void currentChanged(const QModelIndex &current, const QModelIndex &previous) override;
     void selectRow(int i);
 
 Q_SIGNALS:
     void currentChanged(int);
-    void currentChanged(const QByteArray&);
-    void currentChanged(const QByteArray& prev, const QByteArray& current);
+    void currentChanged(const QByteArray &);
+    void currentChanged(const QByteArray &prev, const QByteArray &current);
 };
 
-
-class TermsListModel: public QStringListModel
+class TermsListModel : public QStringListModel
 {
     Q_OBJECT
 public:
-    TermsListModel(Glossary* glossary, const QString& lang, QObject* parent = nullptr): QStringListModel(parent), m_glossary(glossary), m_lang(lang) {}
+    TermsListModel(Glossary *glossary, const QString &lang, QObject *parent = nullptr)
+        : QStringListModel(parent)
+        , m_glossary(glossary)
+        , m_lang(lang)
+    {
+    }
 
-    bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole) override;
-    bool removeRows(int row, int count, const QModelIndex& parent = QModelIndex()) override;
+    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
+    bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex()) override;
 
 public Q_SLOTS:
-    void setEntry(const QByteArray& id);
+    void setEntry(const QByteArray &id);
 
 private:
-    Glossary* m_glossary;
+    Glossary *m_glossary;
     QString m_lang;
     QByteArray m_id;
 };
 
-
-
-
 /*
 class GlossaryItemDelegate : public QItemDelegate//KFileItemDelegate
 {
